==> nextcloud-32.0.0-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/viewer/l10n/zh_CN.js <==
OC.L10N.register(
    "viewer",
    {
    "Viewer" : "查看器",
    "Simple file viewer with slideshow for media" : "带媒体幻灯片的简单文件查看器",
    "Show your latest holiday photos and videos like in the movies, show a glimpse of your latest novel directly from your Nextcloud, choose the best GIF of your collection thanks to the direct preview of your favorites files and many more!" : "以电影的形式显示您最新的假日照片与影片，直接从您的 Nextcloud 看看您最新的小说，借助您最爱的文件与更多东西的直接预览，选择最佳的 GIF！",
    "Your browser does not support audio." : "您的浏览器不支持音频。",
    "Error loading {name}" : "加载 {name} 出错",
    "You are about to overwrite the original file. Are you sure you want to continue?" : "您即将覆盖原始文件，是否确定要继续？",
    "A file with this name already exists. Do you want to overwrite it?" : "同名文件已存在，是​​否要覆盖它？",
    "Confirm overwrite" : "确认覆盖",
    "Cancel" : "取消",
    "Overwrite" : "覆盖",
    "An error occurred while trying to confirm the file overwrite." : "尝试确认文件覆盖时出错。",
    "Image saved" : "图片已保存",
    "Error saving image" : "图片保存错误",
    "Play the live photo" : "播放实时照片",
    "LIVE" : "即时",
    "Your browser does not support videos." : "您的浏览器不支持视频。",
    "This file no longer exists" : "此文件不存在",
    "There is no plugin available to display this file type" : "没有可用于显示此文件类型的插件",
    "Edit" : "编辑",
    "Exit full screen" : "退出全屏",
    "Full screen" : "全屏",
    "Open sidebar" : "打开侧边栏",
    "Download" : "下载",
    "Delete" : "删除",
    "View" : "查看",
    "Name" : "名称",
    "Save" : "保存",
    "Save as" : "另存为",
    "Back" : "返回",
    "Loading …" : "正在加载 …",
    "Reset" : "重置",
    "All changes will be lost." : "所有更改都将丢失。",
    "Are you sure you want to continue?" : "您确定要继续吗？",
    "Apply" : "应用",
    "Warning" : "警告",
    "Confirm" : "确认",
    "Discard changes" : "放弃更改",
    "Undo" : "撤销操作",
    "Redo" : "恢复上个操作",
    "Show original image" : "显示原始图片",
    "Zoom in" : "放大",
    "Zoom out" : "缩小",
    "Toggle zoom menu" : "切换缩放菜单",
    "Adjust" : "调整",
    "Fine-tune" : "微调",
    "Filters" : "过滤器",
    "Watermark" : "水印",
    "Draw" : "画",
    "Resize" : "调整大小",
    "Image name" : "图片名称",
    "Invalid image." : "无效图片",
    "Error while uploading the image." : "上传图片时出错。",
    "are not images" : "不是图片",
    "is not an image" : "不是图片",
    "to be uploaded" : "待上传",
    "Crop" : "裁剪",
    "Original" : "原图",
    "Custom" : "自定义",
    "Square" : "方形",
    "Landscape" : "风景",
    "Portrait" : "肖像",
    "Ellipse" : "椭圆",
    "Classic TV" : "经典电视",
    "CinemaScope" : "CinemaScope",
    "Arrow" : "箭嘴",
    "Blur" : "模糊",
    "Brightness" : "亮度",
    "Contrast" : "对比",
    "Un-flip X" : "取消翻转 X",
    "Flip X" : "翻转 X",
    "Un-flip Y" : "取消翻转 Y",
    "Flip Y" : "翻转 Y",
    "HSV" : "HSV",
    "Hue" : "色调",
    "Saturation" : "饱和",
    "Value" : "值",
    "Image" : "图片",
    "Importing …" : "导入中...",
    "+ Add image" : "+ 添加图片",
    "Upload image" : "上传图片",
    "From gallery" : "从图库",
    "Line" : "线段",
    "Pen" : "笔",
    "Polygon" : "多边形",
    "Sides" : "边",
    "Rectangle" : "矩形",
    "Corner Radius" : "圆角半径",
    "Width in pixels" : "宽度像素",
    "Height in pixels" : "高度像素",
    "Toggle ratio lock" : "切换比例锁定",
    "Reset to original image size" : "重置为原始图像大小",
    "Rotate" : "旋转",
    "Text" : "文本 ",
    "Text spacing" : "文本间距",
    "Text alignment" : "文本对齐方式",
    "Font family" : "字体",
    "Size" : "尺寸",
    "Letter spacing" : "字符间距",
    "Line height" : "行高",
    "Warmth" : "暖度",
    "+ Add watermark" : "+ 添加水印",
    "+ Add text watermark" : "+ 添加文本水印",
    "Choose watermark type" : "选择水印类型",
    "Upload watermark" : "上传水印",
    "Add as text" : "添加为文本",
    "Padding" : "填充",
    "Paddings" : "填充",
    "Shadow" : "阴影",
    "Horizontal" : "水平",
    "Vertical" : "垂直",
    "Opacity" : "透明度",
    "Transparency" : "透明度",
    "Position" : "位置",
    "Stroke" : "笔画",
    "Save image as" : "保存图片为",
    "Extension" : "扩展",
    "Format" : "格式",
    "Name is required." : "名称是必填项。",
    "Quality" : "质量",
    "Saved image size (width x height)" : "保存的图片大小（宽度 × 高度）",
    "Note that the selected crop area is lower than the applied resize which might cause quality decrease" : "请注意，选择的裁剪面积低于应用的调整大小，这可能会导致质量下降",
    "Actual size (100%)" : "实际尺寸（100%）",
    "Fit size" : "适合尺寸",
    "Select image to add …" : "选择要添加的图片…",
    "Failed to load image." : "无法加载图片。",
    "Menu" : "菜单",
    "Width" : "宽度",
    "Height" : "高度",
    "No preview available for this crop item" : "此裁剪项目没有可用的预览"
},
"nplurals=1; plural=0;");

==> nextcloud-32.0.5-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/viewer/l10n/zh_CN.js <==
OC.L10N.register(
    "viewer",
    {
    "Viewer" : "查看器",
    "Simple file viewer with slideshow for media" : "带媒体幻灯片的简单文件查看器",
    "Show your latest holiday photos and videos like in the movies, show a glimpse of your latest novel directly from your Nextcloud, choose the best GIF of your collection thanks to the direct preview of your favorites files and many more!" : "以电影的形式显示您最新的假日照片与影片，直接从您的 Nextcloud 看看您最新的小说，借助您最爱的文件与更多东西的直接预览，选择最佳的 GIF！",
    "Your browser does not support audio." : "您的浏览器不支持音频。",
    "Error loading {name}" : "加载 {name} 出错",
    "You are about to overwrite the original file. Are you sure you want to continue?" : "您即将覆盖原始文件，是否确定要继续？",
    "A file with this name already exists. Do you want to overwrite it?" : "同名文件已存在，是​​否要覆盖它？",
    "Confirm overwrite" : "确认覆盖",
    "Cancel" : "取消",
    "Overwrite" : "覆盖",
    "An error occurred while trying to confirm the file overwrite." : "尝试确认文件覆盖时出错。",
    "Image saved" : "图片已保存",
    "Error saving image" : "图片保存错误",
    "Play the live photo" : "播放实时照片",
    "LIVE" : "即时",
    "Your browser does not support videos." : "您的浏览器不支持视频。",
    "This file no longer exists" : "此文件不存在",
    "There is no plugin available to display this file type" : "没有可用于显示此文件类型的插件",
    "Failed to save file before download" : "下载前无法保存文件",
    "Edit" : "编辑",
    "Exit full screen" : "退出全屏",
    "Full screen" : "全屏",
    "Open sidebar" : "打开侧边栏",
    "Download" : "下载",
    "Delete" : "删除",
    "View" : "查看",
    "Name" : "名称",
    "Save" : "保存",
    "Save as" : "另存为",
    "Back" : "返回",
    "Loading …" : "正在加载 …",
    "Reset" : "重置",
    "All changes will be lost." : "所有更改都将丢失。",
    "Are you sure you want to continue?" : "是否确定要继续？",
    "Apply" : "应用",
    "Warning" : "警告",
    "Confirm" : "确认",
    "Discard changes" : "舍弃更改",
    "Undo" : "撤销操作",
    "Redo" : "恢复上个操作",
    "Show original image" : "显示原始图片",
    "Zoom in" : "放大",
    "Zoom out" : "缩小",
    "Toggle zoom menu" : "切换缩放菜单",
    "Adjust" : "调整",
    "Fine-tune" : "微调",
    "Filters" : "过滤器",
    "Watermark" : "水印",
    "Draw" : "画",
    "Resize" : "调整大小",
    "Image name" : "图片名称",
    "Invalid image." : "无效图片",
    "Error while uploading the image." : "上传图片时出错。",
    "are not images" : "不是图片",
    "is not an image" : "不是图片",
    "to be uploaded" : "待上传",
    "Crop" : "裁剪",
    "Original" : "原图",
    "Custom" : "自定义",
    "Square" : "方形",
    "Landscape" : "风景",
    "Portrait" : "肖像",
    "Ellipse" : "椭圆",
    "Classic TV" : "经典电视",
    "CinemaScope" : "CinemaScope",
    "Arrow" : "箭嘴",
    "Blur" : "模糊",
    "Brightness" : "亮度",
    "Contrast" : "对比",
    "Un-flip X" : "取消翻转 X",
    "Flip X" : "翻转 X",
    "Un-flip Y" : "取消翻转 Y",
    "Flip Y" : "翻转 Y",
    "HSV" : "HSV",
    "Hue" : "色调",
    "Saturation" : "饱和",
    "Value" : "值",
    "Image" : "图片",
    "Importing …" : "导入中...",
    "+ Add image" : "+ 添加图片",
    "Upload image" : "上传图片",
    "From gallery" : "从图库",
    "Line" : "线段",
    "Pen" : "笔",
    "Polygon" : "多边形",
    "Sides" : "边",
    "Rectangle" : "矩形",
    "Corner Radius" : "圆角半径",
    "Width in pixels" : "宽度像素",
    "Height in pixels" : "高度像素",
    "Toggle ratio lock" : "切换比例锁定",
    "Reset to original image size" : "重置为原始图像大小",
    "Rotate" : "旋转",
    "Text" : "文本 ",
    "Text spacing" : "文本间距",
    "Text alignment" : "文本对齐方式",
    "Font family" : "字体",
    "Size" : "尺寸",
    "Letter spacing" : "字符间距",
    "Line height" : "行高",
    "Warmth" : "暖度",
    "+ Add watermark" : "+ 添加水印",
    "+ Add text watermark" : "+ 添加文本水印",
    "Choose watermark type" : "选择水印类型",
    "Upload watermark" : "上传水印",
    "Add as text" : "添加为文本",
    "Padding" : "填充",
    "Paddings" : "填充",
    "Shadow" : "阴影",
    "Horizontal" : "水平",
    "Vertical" : "垂直",
    "Opacity" : "透明度",
    "Transparency" : "透明度",
    "Position" : "位置",
    "Stroke" : "笔画",
    "Save image as" : "保存图片为",
    "Extension" : "扩展",
    "Format" : "格式",
    "Name is required." : "名称是必填项。",
    "Quality" : "质量",
    "Saved image size (width x height)" : "保存的图片大小（宽度 × 高度）",
    "Note that the selected crop area is lower than the applied resize which might cause quality decrease" : "请注意，选择的裁剪面积低于应用的调整大小，这可能会导致质量下降",
    "Actual size (100%)" : "实际尺寸（100%）",
    "Fit size" : "适合尺寸",
    "Select image to add …" : "选择要添加的图片…",
    "Failed to load image." : "无法加载图片。",
    "Menu" : "菜单",
    "Width" : "宽度",
    "Height" : "高度",
    "No preview available for this crop item" : "此裁剪项目没有可用的预览"
},
"nplurals=1; plural=0;");
